@@ -19,11 +19,11 @@
 #endif
 
 #include <errno.h>
-#include <error.h>
 #include <stdio.h>
 #include <fcntl.h>
 #include <unistd.h>
 #include <libelf.h>
+#include "system.h"
 
 int
 main (int argc __attribute__ ((unused)), char *argv[])
